<?php


namespace WPEasyTranslate\View;

use MetatickPluginLib\View\GetObjectTrait;
use MetatickPluginLib\View\MenuPageView;
use MetatickPluginLib\View\RequireLicenseTrait;
use MetatickPluginLib\View\TemplateResponseTrait;
use MetatickPluginLib\View\UpdateObjectTrait;
use WPEasyTranslate\Model\Settings as SettingsModel;
use WPEasyTranslate\Plugin;
use WPEasyTranslate\Service\Language;

class Settings extends MenuPageView
{
    use GetObjectTrait;
    use UpdateObjectTrait;
    use TemplateResponseTrait;
    use RequireLicenseTrait;

    protected $parent_menu_title = 'WP Easy Translate';
    protected $menu_title = 'Settings';
    protected $page_title = 'Settings';
    protected $slug = Plugin::SLUG;
    protected $type = self::MENU;
    protected $icon = 'dashicons-format-chat';

    protected $template = 'settings.html';

    protected static $fields = [
        'enabled' => self::CHECK,
        'background' => self::INPUT,
        'color' => self::INPUT,
        'location' => self::INPUT,
        'english_flag' => self::INPUT,

        'af' => self::CHECK,
        'sq' => self::CHECK,
        'am' => self::CHECK,
        'ar' => self::CHECK,
        'hy' => self::CHECK,
        'az' => self::CHECK,
        'eu' => self::CHECK,
        'be' => self::CHECK,
        'bn' => self::CHECK,
        'bs' => self::CHECK,
        'bg' => self::CHECK,
        'ca' => self::CHECK,
        'ceb' => self::CHECK,
        'ny' => self::CHECK,
        'zh-CN' => self::CHECK,
        'zh-TW' => self::CHECK,
        'co' => self::CHECK,
        'hr' => self::CHECK,
        'cs' => self::CHECK,
        'da' => self::CHECK,
        'nl' => self::CHECK,
        'en' => self::CHECK,
        'et' => self::CHECK,
        'tl' => self::CHECK,
        'fi' => self::CHECK,
        'fr' => self::CHECK,
        'fy' => self::CHECK,
        'gl' => self::CHECK,
        'ka' => self::CHECK,
        'de' => self::CHECK,
        'el' => self::CHECK,
        'gu' => self::CHECK,
        'ht' => self::CHECK,
        'ha' => self::CHECK,
        'haw' => self::CHECK,
        'he' => self::CHECK,
        'hi' => self::CHECK,
        'hmn' => self::CHECK,
        'hu' => self::CHECK,
        'is' => self::CHECK,
        'ig' => self::CHECK,
        'id' => self::CHECK,
        'ga' => self::CHECK,
        'it' => self::CHECK,
        'ja' => self::CHECK,
        'jw' => self::CHECK,
        'kn' => self::CHECK,
        'kk' => self::CHECK,
        'km' => self::CHECK,
        'ko' => self::CHECK,
        'ku' => self::CHECK,
        'ky' => self::CHECK,
        'lo' => self::CHECK,
        'lv' => self::CHECK,
        'lt' => self::CHECK,
        'lb' => self::CHECK,
        'mk' => self::CHECK,
        'mg' => self::CHECK,
        'ms' => self::CHECK,
        'ml' => self::CHECK,
        'mt' => self::CHECK,
        'mi' => self::CHECK,
        'mr' => self::CHECK,
        'mn' => self::CHECK,
        'my' => self::CHECK,
        'ne' => self::CHECK,
        'no' => self::CHECK,
        'ps' => self::CHECK,
        'fa' => self::CHECK,
        'pl' => self::CHECK,
        'pt' => self::CHECK,
        'pa' => self::CHECK,
        'ro' => self::CHECK,
        'ru' => self::CHECK,
        'sm' => self::CHECK,
        'gd' => self::CHECK,
        'sr' => self::CHECK,
        'st' => self::CHECK,
        'sn' => self::CHECK,
        'sd' => self::CHECK,
        'si' => self::CHECK,
        'sk' => self::CHECK,
        'sl' => self::CHECK,
        'so' => self::CHECK,
        'es' => self::CHECK,
        'su' => self::CHECK,
        'sw' => self::CHECK,
        'sv' => self::CHECK,
        'tg' => self::CHECK,
        'ta' => self::CHECK,
        'te' => self::CHECK,
        'th' => self::CHECK,
        'tr' => self::CHECK,
        'uk' => self::CHECK,
        'ur' => self::CHECK,
        'uz' => self::CHECK,
        'vi' => self::CHECK,
        'cy' => self::CHECK,
        'xh' => self::CHECK,
        'yi' => self::CHECK,
        'yo' => self::CHECK,
        'zu' => self::CHECK
    ];

    public static function license(){
        return Plugin::license();
    }

    public function get_context(){
        return [
            'plugin' => Plugin::instance(),
            'languages' => Language::as_array(Language::all(), null),
            'object' => $this->get_object(),
            'license' => static::license()
        ];
    }

    public function get_object()
    {
        return Plugin::settings();
    }

    public function __construct($template_path)
    {
        parent::__construct($template_path);
        add_filter("{$this->slug}_license_description", [$this, 'license_description'], 10, 2);
    }

    public function license_description($_, $license){
        $edition = 'Standard Edition';
        if($license->has_feature('professional')){
            $edition = 'Professional Edition';
        }
        if($license->has_feature('developer')){
            $edition .= ' with Developer Rights';
        }
        return $edition;
    }
}