<?php


namespace MetatickPluginLib\Http\Client;


class Client
{
    protected $default_options = [];

    public function __construct($default_options = [])
    {
        $this->default_options = $default_options;
    }

    public function get($url, $options = []) {
        return $this->request($url, 'GET', $options);
    }

    public function post($url, $options = []) {
        return $this->request($url, 'POST', $options);
    }

    public function put($url, $options = []) {
        return $this->request($url, 'PUT', $options);
    }

    public function patch($url, $options = []) {
        return $this->request($url, 'PATCH', $options);
    }

    public function delete($url, $options = []) {
        return $this->request($url, 'DELETE', $options);
    }

    public function options($url, $options = []) {
        return $this->request($url, 'OPTIONS', $options);
    }

    public function trace($url, $options = []) {
        return $this->request($url, 'TRACE', $options);
    }

    public function head($url, $options = []) {
        return $this->request($url, 'HEAD', $options);
    }

    public function request($url, $method, $options){
        $args = array_merge($this->default_options, $options, ['method' => $method]);
        $response = wp_remote_request($url, $args);

        if(is_wp_error($response)){
            throw new HttpClientException($response->get_error_message());
        }

        $response = new Response($url, $response);

        return $response;
    }
}