<?php


namespace MetatickPluginLib\Request;


use ArrayAccess;

class RequestParams implements ArrayAccess
{
    protected $data = [];
    protected $case_insensitive = false;

    public function __construct($data, $case_insensitive=false)
    {
        $this->data = $data;
        $this->case_insensitive = $case_insensitive;

        if($this->case_insensitive){
            array_change_key_case($this->data);
        }
    }

    public function transform_key($key){
        if($this->case_insensitive){
            return strtolower($key);
        }
        return $key;
    }

    public function get($name, $default=null){
        $name = $this->transform_key($name);
        if($this->offsetExists($name)){
            return $this->offsetGet($name);
        }
        return $default;
    }

    public function offsetSet($offset, $value)
    {
        $offset = $this->transform_key($offset);

        if (is_null($offset)) {
            $this->data[] = $value;
        } else {
            $this->data[$offset] = $value;
        }
    }

    public function offsetExists($offset)
    {
        $offset = $this->transform_key($offset);

        return isset($this->data[$offset]);
    }

    public function offsetUnset($offset)
    {
        $offset = $this->transform_key($offset);

        if ($this->offsetExists($offset)) {
            unset($this->data[$offset]);
        }
    }

    public function offsetGet($offset)
    {
        $offset = $this->transform_key($offset);

        return $this->offsetExists($offset) ? $this->data[$offset] : null;
    }

}