<?php


namespace MetatickPluginLib\View;


use MetatickPluginLib\Request\Request;

class MenuPageView extends ViewBase
{
    const MENU = 'menu';
    const SUBMENU = 'submenu';
    const OPTIONS = 'options';

    protected $parent_menu_title = null;
    protected $menu_title = null;
    protected $page_title = null;
    protected $slug = null;
    protected $type = self::MENU;

    protected $parent = null;
    protected $icon = null;

    protected $capability = 'manage_options';

    public function __construct($template_path) {
        parent::__construct($template_path);

        add_action('admin_menu', [$this, 'admin_menu']);
        add_action('admin_head', [$this, 'admin_head']);

        if($this->is_request()){
            add_action('admin_notices', [$this, 'admin_notices']);
            add_action('admin_init', [$this, 'handle_dispatch']);
        }
    }

    function admin_menu(){
        if($this->type === static::MENU){
            add_menu_page(
                $this->page_title,
                $this->parent_menu_title,
                $this->capability,
                $this->slug,
                [$this, 'render'],
                $this->icon
            );
            add_submenu_page(
                $this->slug,
                $this->page_title,
                $this->menu_title,
                $this->capability,
                $this->slug,
                [$this, 'render']
            );
        }elseif ($this->type === static::SUBMENU){
            add_submenu_page(
                $this->parent,
                $this->page_title,
                $this->menu_title,
                $this->capability,
                $this->slug,
                [$this, 'render']
            );
        }elseif ($this->type === static::OPTIONS) {
            add_options_page(
                $this->page_title,
                $this->menu_title,
                $this->capability,
                $this->slug,
                [$this, 'render']
            );
        }
    }

    function admin_head() {
        //useful for adding custom css for the icon/menu
    }

    public function is_request(){
        if(defined('WP_ADMIN') && WP_ADMIN){
            $request = Request::instance();
            if($request->GET()->get('page') === $this->slug){
                return true;
            }
        }
        return false;
    }

    public function admin_notices(){
        $messages = $this->read_messages();
        if($messages && count($messages) > 0) {
            foreach ($messages as $message) {
                ?>
                <div class="notice notice-<?php echo $message[0]; ?> is-dismissible">
                    <p><?php echo $message[1]; ?></p>
                </div>
                <?php
            }
        }
    }

    public function render(){
        echo $this->response->get_body();
    }
}